@@ -60,8 +60,10 @@ void IndicatorHelper::iconPathHook()
 
 int IndicatorHelper::daemonHook(QProcess &kdeconnectd)
 {
+#ifdef USE_PRIVATE_DBUS
     // Unset launchctl env, avoid block
     DBusHelper::macosUnsetLaunchctlEnv();
+#endif
 
     // Start kdeconnectd
     m_splashScreen->showMessage(i18n("Launching daemon") + QStringLiteral("\n"), Qt::AlignHCenter | Qt::AlignBottom, Qt::white);
@@ -125,7 +127,9 @@ void IndicatorHelper::systrayIconHook(KStatusNotifierItem &systray)
 {
     const QString iconPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("kdeconnect-icons"), QStandardPaths::LocateDirectory);
     if (!iconPath.isNull()) {
-        systray.setIconByName(QStringLiteral("kdeconnectindicatordark"));
+        auto icon = QIcon::fromTheme(QStringLiteral("kdeconnectindicator"));
+        icon.setIsMask(true); // Make icon adapt to menu bar color
+        systray.setIconByPixmap(icon);
     } else {
         // We are in macOS dev env, just continue
         qWarning() << "Fail to find indicator icon, continue anyway";
