@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "mpriscontrolplugin.h"
@@ -174,6 +160,14 @@ void MprisControlPlugin::propertiesChanged(const QString& propertyInterface, con
         np.set(QStringLiteral("isPlaying"), playing);
         somethingToSend = true;
     }
+    if (properties.contains(QStringLiteral("LoopStatus"))) {
+        np.set(QStringLiteral("loopStatus"), properties[QStringLiteral("LoopStatus")]);
+        somethingToSend = true;
+    }
+    if (properties.contains(QStringLiteral("Shuffle"))) {
+        np.set(QStringLiteral("shuffle"), properties[QStringLiteral("Shuffle")].toBool());
+        somethingToSend = true;
+    }
     if (properties.contains(QStringLiteral("CanPause"))) {
         np.set(QStringLiteral("canPause"), properties[QStringLiteral("CanPause")].toBool());
         somethingToSend = true;
@@ -295,6 +289,16 @@ bool MprisControlPlugin::receivePacket (const NetworkPacket& np)
         //TODO: Check for valid actions, currently we trust anything the other end sends us
         mprisInterface.call(action);
     }
+    if (np.has(QStringLiteral("setLoopStatus"))) {
+        const QString& loopStatus = np.get<QString>(QStringLiteral("setLoopStatus"));
+        qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Setting loopStatus" << loopStatus << "to" << serviceName;
+        mprisInterface.setLoopStatus(loopStatus);
+    }
+    if (np.has(QStringLiteral("setShuffle"))) {
+        bool shuffle = np.get<bool>(QStringLiteral("setShuffle"));
+        qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Setting shuffle" << shuffle << "to" << serviceName;
+        mprisInterface.setShuffle(shuffle);
+    }
     if (np.has(QStringLiteral("setVolume"))) {
         double volume = np.get<int>(QStringLiteral("setVolume"))/100.f;
         qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Setting volume" << volume << "to" << serviceName;
@@ -332,6 +336,18 @@ bool MprisControlPlugin::receivePacket (const NetworkPacket& np)
         answer.set(QStringLiteral("canGoPrevious"), mprisInterface.canGoPrevious());
         answer.set(QStringLiteral("canSeek"), mprisInterface.canSeek());
 
+        // LoopStatus is an optional field
+        if (mprisInterface.property("LoopStatus").isValid()) {
+            const QString& loopStatus = mprisInterface.loopStatus();
+            answer.set(QStringLiteral("loopStatus"),loopStatus);
+        }
+
+        // Shuffle is an optional field
+        if (mprisInterface.property("Shuffle").isValid()) {
+            bool shuffle = mprisInterface.shuffle();
+            answer.set(QStringLiteral("shuffle"),shuffle);
+        }
+
         somethingToSend = true;
     }
     if (np.get<bool>(QStringLiteral("requestVolume"))) {
