@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "share_config.h"
@@ -29,7 +15,7 @@
 K_PLUGIN_FACTORY(ShareConfigFactory, registerPlugin<ShareConfig>();)
 
 ShareConfig::ShareConfig(QWidget* parent, const QVariantList& args)
-    : KdeConnectPluginKcm(parent, args, QStringLiteral("kdeconnect_share_config"))
+    : KdeConnectPluginKcm(parent, args, QStringLiteral("kdeconnect_share"))
     , m_ui(new Ui::ShareConfigUi())
 {
     m_ui->setupUi(this);
@@ -59,7 +45,7 @@ void ShareConfig::load()
     KCModule::load();
 
     const auto standardPath = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
-    m_ui->kurlrequester->setText(config()->get<QString>(QStringLiteral("incoming_path"), standardPath));
+    m_ui->kurlrequester->setText(config()->getString(QStringLiteral("incoming_path"), standardPath));
 
     Q_EMIT changed(false);
 }
