@@ -18,6 +18,8 @@
 int main(int argc, char** argv)
 {
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
